==> de.bsvrz.buv.plugin.dobj.source_4.0.0.201905071350.jar: de/bsvrz/buv/plugin/dobj/decorator/LinienstaerkeFigure.java <==
/*
 * Rahmenwerk-Plug-in "Darstellungsobjekte"
 * Copyright (C) 2018 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weissenfelser Strasse 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */
package de.bsvrz.buv.plugin.dobj.decorator;

import org.eclipse.draw2d.IFigure;

import de.bsvrz.buv.plugin.dobj.decorator.model.Zoomverhalten;

public interface LinienstaerkeFigure extends IFigure {

	int getLinienstaerke();

	void setLinienstaerke(int linienstaerke);

	default Zoomverhalten getZoomverhalten() {
		return Zoomverhalten.STATISCHES_ZOOMVERHALTEN;
	}

	default void setZoomverhalten(final Zoomverhalten zoomverhalten) {
		// leere default Implementierung
	}

	default void setMinimaleZoomstufeLinienstaerke(final double minimaleZoomstufe) {
		// leere default Implementierung
	}

	default double getMinimaleZoomstufeLinienstaerke() {
		return Double.MIN_NORMAL;
	}

	default void setMaximaleZoomstufeLinienstaerke(final double maximaleZoomstufe) {
		// leere default Implementierung
	}

	default double getMaximaleZoomstufeLinienstaerke() {
		return Double.MAX_VALUE;
	}

	default void setMinimaleLinienstaerke(final int minimaleLinienstarke) {
		// leere default Implementierung
	}

	default int getMinimaleLinienstaerke() {
		return getLinienstaerke();
	}

	default void setMaximaleLinienstaerke(final int maximaleLinienstaerke) {
		// leere default Implementierung
	}

	default int getMaximaleLinienstaerke() {
		return getLinienstaerke();
	}

}

==> de.bsvrz.buv.plugin.dobj.source_4.5.0.202510170820.jar: de/bsvrz/buv/plugin/dobj/decorator/LinienstaerkeFigure.java <==
/*
 * Rahmenwerk-Plug-in "Darstellungsobjekte"
 * Copyright (C) 2023 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weissenfelser Strasse 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */
package de.bsvrz.buv.plugin.dobj.decorator;

import org.eclipse.draw2d.IFigure;

import de.bsvrz.buv.plugin.dobj.decorator.model.Zoomverhalten;

public interface LinienstaerkeFigure extends IFigure {

	int getLinienstaerke();

	void setLinienstaerke(int linienstaerke);

	default Zoomverhalten getLinienstaerkeZoomverhalten() {
		return Zoomverhalten.STATISCHES_ZOOMVERHALTEN;
	}

	default void setLinienstaerkeZoomverhalten(final Zoomverhalten zoomverhalten) {
		// leere default Implementierung
	}

	default void setLinienstaerkeMinimaleZoomstufe(final double minimaleZoomstufe) {
		// leere default Implementierung
	}

	default double getLinienstaerkeMinimaleZoomstufe() {
		return Double.MIN_NORMAL;
	}

	default void setLinienstaerkeMaximaleZoomstufe(final double maximaleZoomstufe) {
		// leere default Implementierung
	}

	default double getLinienstaerkeMaximaleZoomstufe() {
		return Double.MAX_VALUE;
	}

	default void setLinienstaerkeMinimum(final int minimaleLinienstarke) {
		// leere default Implementierung
	}

	default int getLinienstaerkeMinimum() {
		return getLinienstaerke();
	}

	default void setLinienstaerkeMaximum(final int maximaleLinienstaerke) {
		// leere default Implementierung
	}

	default int getLinienstaerkeMaximum() {
		return getLinienstaerke();
	}

}
